@@ -7,8 +7,7 @@ void IntegrityScanner::copy(Process &src, string const &fname)
     ofstream currentReport(fname.c_str());
 
     if (!currentReport)
-        d_stealthLog << "Can't open `" << fname << "' to write" << 
-                        StealthEnums::leave;
+        fmsg << "Can't open `" << fname << "' to write" << noidl;
 
     m3 << "copy: about to read child input" << endl;
 
