@@ -2,8 +2,9 @@
 
 void IntegrityScanner::setSkip()
 {
-    ifstream in;
-    Exception::open(in, d_skipFilePath);
+    ifstream in(d_skipFile);
+    if (not in)
+        fmsg << "cannot read skip-file `" << d_skipFile << '\'' << noidl;
 
     for_each(
         istream_iterator<StringLine>(in), istream_iterator<StringLine>(), 
@@ -20,3 +21,4 @@ void IntegrityScanner::setSkip()
 
 
 
+
