@@ -2,6 +2,5 @@
 
 void Stealth::terminate()
 {
-    logMsg("terminates");
-    d_run.setMode(LEAVE);
+    timestamp("terminates");
 }
